package de.uniba.kinf.geogames.esriguesstimate.activities;

import android.app.AlertDialog;
import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.text.Editable;
import android.text.InputFilter;
import android.text.method.DigitsKeyListener;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.WindowManager;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import de.uniba.kinf.geogames.esriguesstimate.R;
import de.uniba.kinf.geogames.esriguesstimate.data.GeoLocation;
import de.uniba.kinf.geogames.esriguesstimate.ui.GeoLocationAdapter;


public class BlindGuess extends ActionBarActivity implements GameService.GameServiceListener {

    protected static final String TAG = "BlindGuess";

    protected GameService gameService;
    protected boolean gameServiceBound;

    int playerScore = 0;
    int remainingSeconds = 0;

    protected ListView locListView;
    private ActionBar actionBar;
    protected TextView scoreText;
    protected TextView timeText;

    // ===== Activity Methods =====

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_blind_pick);

        actionBar = getSupportActionBar();
        scoreText = (TextView) findViewById(R.id.scoreText);
        timeText = (TextView) findViewById(R.id.timeText);
        locListView = (ListView) findViewById(R.id.blind_pick_listview);

        Intent intent = new Intent(this, GameService.class);
        bindService(intent, gameServiceCon, Context.BIND_AUTO_CREATE);
    }

    @Override
    protected void onDestroy() {
        if(gameServiceBound) {
            gameService.unregisterListener(BlindGuess.this);
            unbindService(gameServiceCon);
            gameServiceBound = false;
        }
        stopService(new Intent(this, GameService.class));
        super.onDestroy();
    }

    @Override
    public void onBackPressed() {
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_blind_pick, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    // ===== Private Methods =====

    private void setupListAdapter(final ListView listView, final GeoLocationAdapter adapter) {
        listView.setAdapter(adapter);
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(final AdapterView<?> a, final View v, final int position, long id) {
                final GeoLocation locGuess = (GeoLocation) locListView.getAdapter().getItem(position);
                Log.d(TAG, "Picked location" + locGuess);

                final EditText input = new EditText(BlindGuess.this);
                input.setFilters(new InputFilter[] {
                        new InputFilter.LengthFilter(4),
                        DigitsKeyListener.getInstance(),
                });
                input.setKeyListener(DigitsKeyListener.getInstance());

                AlertDialog dialog = new AlertDialog.Builder(BlindGuess.this)
                        .setTitle("Guess your distance to: "+locGuess.getName())
                        .setMessage("Enter the distance (as the crow/drone flies, in meters) you think it is to "+locGuess.getName())
                        .setView(input)
                        .setPositiveButton("Ok", new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int whichButton) {
                                Editable value = input.getText();
                                String valueString = value.toString();
                                if (valueString.equals("")) {
                                    return;
                                }
                                Log.d(TAG, valueString);
                                int distance = Integer.valueOf(value.toString());
                                locGuess.setDistanceGuess(distance);
                                gameService.removeGuess(locGuess);
                                gameService.addGuess(locGuess);
                                locListView.invalidateViews();
                            }
                        }).setNegativeButton("Clear", new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int whichButton) {
                                locGuess.removeGuess();
                                gameService.removeGuess(locGuess);
                                locListView.invalidateViews();
                            }
                }).create();
                dialog.getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_VISIBLE);
                dialog.show();
            }
        });
    }

    private void updatePlayerStats() {
        scoreText.setText("Score: "+playerScore);
        timeText.setText("" + remainingSeconds + " seconds remaining");
    }

    // ===== Game Service Listener Methods =====

    @Override
    public void updateRemainingSeconds(int seconds) {
        remainingSeconds = seconds;
        updatePlayerStats();
    }

    @Override
    public void updatePlayerScore(int score, int deltaScore) {
        Log.d(TAG, "Player score updated ("+score+")");
        playerScore = score;
        Toast.makeText(getApplicationContext(), "Scored " + deltaScore + " points!",
                Toast.LENGTH_LONG).show();
        updatePlayerStats();
    }

    @Override
    public void updatePlayerPosition() {}

    @Override
    public void updateTargetPosition() {
        finish();
    }

    @Override
    public void playerReachedTarget(boolean gamesStart) {}

    @Override
    public void gameOver() {}

    // ===== Game Service Connection =====

    private ServiceConnection gameServiceCon = new ServiceConnection() {

        @Override
        public void onServiceConnected(ComponentName className, IBinder service) {
            GameService.LocalBinder binder = (GameService.LocalBinder) service;
            gameService = binder.getService();
            gameServiceBound = true;
            gameService.registerListener(BlindGuess.this);
            Log.d(TAG, "Service bound");

            actionBar.setTitle("Guesstimate - "+gameService.getMapName());
            actionBar.setSubtitle("Make your guesses.");

            GeoLocationAdapter listAdapter = new GeoLocationAdapter(getApplicationContext(),
                    gameService.getLocationsToPick());
            setupListAdapter(locListView, listAdapter);
        }

        @Override
        public void onServiceDisconnected(ComponentName arg0) {
        }
    };

}
