package de.uniba.kinf.geogames.esriguesstimate.activities;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.net.http.SslError;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.ViewGroup;
import android.webkit.SslErrorHandler;
import android.widget.RadioGroup;

import com.esri.android.oauth.OAuthView;
import com.esri.core.io.UserCredentials;
import com.esri.core.map.CallbackListener;
import com.esri.core.portal.Portal;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import javax.crypto.SecretKey;

import de.uniba.kinf.geogames.esriguesstimate.R;

public class EsriLogin extends ActionBarActivity {

    protected static final String TAG = "OAuth2Sample";

    // -- Login --
    private static boolean loggedIn = false;
    private static UserCredentials userLoginCredentials;

    // -- UI --
    private AlertDialog alertDialog;
    private AlertDialog encryptionDialog;

    // ===== Activity Methods =====

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_esri_login);
        Log.d(TAG, "Created");
        showOAuth(EsriLogin.this);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_esri_login, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    // ===== Login =====

    /**
     * display OAuthView in a popup and prompt user to login
     *
     * @param context
     */
    private void showOAuth(Context context) {
        Log.d(TAG, "Showing OAuth view");
        // Create an instance of OAuthView, set client_id in string resource
        OAuthView oAuthView = new OAuthView(context, getResources().getString(R.string.portal_url),
                getResources().getString(R.string.client_id), new CallbackListener<UserCredentials>() {
            @Override
            public void onError(Throwable e) {
                Log.e(TAG, "", e);
            }

            @Override
            public void onCallback(UserCredentials credentials) {
                // set UserCredentials
                setCredentials(credentials);
                setResult(RESULT_OK);
                finish();
            }
        });
        // handle SSL errors
        oAuthView.setOnSslErrorListener(new OAuthView.OnSslErrorListener() {
            @Override
            public void onReceivedSslError(OAuthView view, SslErrorHandler handler, SslError error) {
                Log.d(TAG, "" + error);
            }

        });
        // add OAuthview to the Activity
        ((ViewGroup) findViewById(R.id.loginView)).addView(oAuthView,
                new ViewGroup.LayoutParams(RadioGroup.LayoutParams.MATCH_PARENT,
                        ViewGroup.LayoutParams.MATCH_PARENT));

    }

    /**
     * Setter for UserCredentials
     *
     * @param credentials
     */
    private void setCredentials(UserCredentials credentials) {
        Log.d(TAG, "Credentials set");
        EsriLogin.loggedIn = true;
        EsriLogin.userLoginCredentials = credentials;
    }

    /**
     * returns user credentials saved on internal storage
     *
     * @return UserCredentials
     */
    public static UserCredentials getCredentials() {
        Log.d(TAG, "Credentials requested");
        return EsriLogin.userLoginCredentials;
    }

    public static boolean isLoggedIn() {
        return loggedIn;
    }

    public static Portal getPortal(Context context) {
        Portal portal;
        String portalUrl = context.getResources().getString(R.string.portal_url);
        if(EsriLogin.isLoggedIn()) {
            portal = new Portal(portalUrl, EsriLogin.getCredentials());
        } else {
            portal = new Portal(portalUrl, null);
        }
        return portal;
    }

    public static void loggout() {
        EsriLogin.loggedIn = false;
        EsriLogin.userLoginCredentials = null;
        Log.d(TAG, "Logged out");
    }

}
