package de.uniba.kinf.geogames.esriguesstimate.activities;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.IBinder;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import de.uniba.kinf.geogames.esriguesstimate.R;
import de.uniba.kinf.geogames.esriguesstimate.ui.GeoLocationAdapter;

public class GameOver extends ActionBarActivity implements GameService.GameServiceListener {

    protected static final String TAG = "BlindGuess";

    protected GameService gameService;
    protected boolean gameServiceBound;

    protected TextView mapNameText;
    protected TextView mapDurationText;
    protected TextView resultText;
    protected Button playAgainBtn;
    protected Button quitBtn;

    // ===== Activity Methods =====

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_game_over);

        mapNameText = (TextView) findViewById(R.id.mapNameText);
        mapDurationText = (TextView) findViewById(R.id.mapDurationText);
        resultText = (TextView) findViewById(R.id.resultText);

        playAgainBtn = (Button) findViewById(R.id.playAgainBtn);
        quitBtn = (Button) findViewById(R.id.quitBtn);

        playAgainBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getBaseContext(), MainMenu.class);
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
                startActivity(intent);
                finish();
            }
        });
        quitBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getBaseContext(), MainMenu.class);
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
                intent.putExtra("EXIT", true);
                startActivity(intent);
                finish();
            }
        });

        Intent intent = new Intent(this, GameService.class);
        bindService(intent, gameServiceCon, Context.BIND_AUTO_CREATE);

    }

    @Override
    protected void onDestroy() {
        stopService(new Intent(this, GameService.class));
        super.onDestroy();

    }

    @Override
    public void onBackPressed() {
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_game_over, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }


    // ===== Game Service Listener Methods =====

    @Override
    public void updateRemainingSeconds(int seconds) {}

    @Override
    public void updatePlayerScore(int score, int deltaScore) {}

    @Override
    public void updatePlayerPosition() {}

    @Override
    public void updateTargetPosition() {}

    @Override
    public void playerReachedTarget(boolean gamesStart) {}

    @Override
    public void gameOver() {}



    // ===== Game Service Connection =====

    private ServiceConnection gameServiceCon = new ServiceConnection() {

        @Override
        public void onServiceConnected(ComponentName className, IBinder service) {
            GameService.LocalBinder binder = (GameService.LocalBinder) service;
            gameService = binder.getService();
            gameServiceBound = true;
            gameService.registerListener(GameOver.this);
            Log.d(TAG, "Service bound");

            mapNameText.setText(gameService.getMapName());
            mapDurationText.setText("Game duration: "+gameService.getGameDuration().text);
            resultText.setText("Congratulations:\nYou scored "+gameService.getPlayerScore()+" points.");

            stopService(new Intent(GameOver.this, GameService.class));

        }

        @Override
        public void onServiceDisconnected(ComponentName arg0) {
        }
    };


}
