package de.uniba.kinf.geogames.esriguesstimate.activities;

import android.app.ProgressDialog;
import android.content.Intent;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.StrictMode;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.ViewAnimator;

import com.esri.android.map.MapView;
import com.esri.core.portal.Portal;
import com.esri.core.portal.PortalItem;
import com.esri.core.portal.PortalQueryParams;
import com.esri.core.portal.WebMap;

import java.util.ArrayList;
import java.util.List;

import de.uniba.kinf.geogames.esriguesstimate.R;
import de.uniba.kinf.geogames.esriguesstimate.game.GameDuration;

public class MainMenu extends ActionBarActivity {

    protected static final String TAG = "MainMenu";

    // -- Login --
    protected static final int LOGIN_RESULT = 0;

    // -- UI --
    private ViewAnimator viewAnimator;
    private Animation slideInLeft, slideOutRight;

    private MapView bgMap;
    private Button playBtn;
    private Button startGameBtn;
    private Button tutorialBtn;
    private Button playPublicBtn;
    private Button loginBtn;
    private Spinner fieldSpinner;
    private Spinner gameDurationSpinner;
    private ArrayAdapter<GameDuration> gameDurationAdapter;
    private ProgressDialog progressDialog;

    // -- Game Config --
    protected ArrayList<String> fieldNames = new ArrayList<String>();
    protected ArrayList<String> fieldIds = new ArrayList<String>();
    protected GameDuration selectedGameDuration = GameDuration.MIN10;
    protected String selectedFieldId;


    // ===== Activity Methods =====

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.d(TAG, "Creating activity");
        super.onCreate(savedInstanceState);
        // Exit?
        if( getIntent().getBooleanExtra("EXIT", false)){
            finish();
        }
        // Disable strict mode
        StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
        StrictMode.setThreadPolicy(policy);
        // Init UI
        setContentView(R.layout.activity_main_menu);
        initUi();
        Log.d(TAG, "Created");
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main_menu, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onBackPressed() {
        viewAnimator.setDisplayedChild(0);
    }

    // ===== UI =====

    private void initUi() {
        Log.d(TAG, "Initializing UI");
        bgMap = (MapView) findViewById(R.id.bg_map);
        bgMap.setClickable(false);

        viewAnimator = (ViewAnimator)findViewById(R.id.viewanimator);
        slideInLeft = AnimationUtils.loadAnimation(this, android.R.anim.fade_in);
        slideOutRight = AnimationUtils.loadAnimation(this, android.R.anim.fade_out);
        viewAnimator.setInAnimation(slideInLeft);
        viewAnimator.setOutAnimation(slideOutRight);
        // - Slide 1 -
        playBtn = (Button) findViewById(R.id.play_btn);
        playBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
//                startGeotriggerService();
                viewAnimator.showNext();
            }
        });
        tutorialBtn = (Button) findViewById(R.id.tutorial_btn);
        tutorialBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(getBaseContext(), Tutorial.class));
            }});
        // - Slide 2 -
        playPublicBtn = (Button) findViewById(R.id.playPublicBtn);
        playPublicBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final ProgressDialog progress = new ProgressDialog(MainMenu.this);
                progress.setTitle("Please Wait");
                progress.setMessage("Loading game fields...");
                progress.setIndeterminate(true);
                progress.show();
                new AsyncTask<Void, Void, Void>()
                {
                    @Override
                    protected Void doInBackground(Void... params)
                    {
                        runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
                                catchGameFields(false);
                            }
                        });
                        return null;
                    }

                    @Override
                    protected void onPostExecute(Void result)
                    {
                        progress.dismiss();
                        viewAnimator.showNext();
                    }
                }.execute();
            }
        });
        loginBtn = (Button) findViewById(R.id.login_btn);
        loginBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getBaseContext(), EsriLogin.class);
                startActivityForResult(intent, LOGIN_RESULT);

            }
        });
        // - Slide 3 -
        fieldSpinner = (Spinner) findViewById(R.id.fieldSpinner);
        gameDurationSpinner = (Spinner) findViewById(R.id.duration_spinner);
        gameDurationAdapter = new ArrayAdapter<>(this, R.layout.spinner_item, GameDuration.values());
        gameDurationSpinner.setAdapter(gameDurationAdapter);
        gameDurationSpinner.setSelection(selectedGameDuration.ordinal());
        // - Slide 4 -
        startGameBtn = (Button) findViewById(R.id.startGameBtn);
        startGameBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                selectedFieldId = fieldIds.get(fieldSpinner.getSelectedItemPosition());
                selectedGameDuration = GameDuration.values()[gameDurationSpinner.getSelectedItemPosition()];
                startGameService();
                startGame();

            }
        });
    }

    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == LOGIN_RESULT) {
            if (resultCode == RESULT_OK) {
                Log.d(TAG, "Login successfull");
                catchGameFields(true);
                viewAnimator.showNext();
            }
        }
    }

    // ===== Private Methods ====

    private void catchGameFields(boolean privateOnly) {
        Log.d(TAG, "Catching game fields");
        fieldNames.clear();
        fieldIds.clear();

        Portal portal = EsriLogin.getPortal(this);
        String portalQuery = getResources().getString(R.string.feature_service_query);
        PortalQueryParams pqp = new PortalQueryParams(portalQuery);
        if(privateOnly) {
            pqp.setCanSearchPublic(false);
        } else {
            pqp.setCanSearchPublic(true);
        }
        try {
            List<PortalItem> items = portal.findItems(pqp).getResults();
            Log.d(TAG, "Found " + items.size() +" portal items");
            for (PortalItem item : items) {
                WebMap map = WebMap.newInstance(item);
                String mapName = map.getInfo().getTitle();
                String mapId = map.getInfo().getItemId();
                fieldNames.add(mapName);
                fieldIds.add(mapId);
                Log.d(TAG, "Found map: " + mapName + " ["+mapId+"]");
            }
        } catch (Exception e) {
            Log.d(TAG, "Error while catching game fields", e);
        }

        ArrayAdapter<String> adapter = new ArrayAdapter<>(MainMenu.this, R.layout.spinner_item,
                fieldNames);
        adapter.setDropDownViewResource(R.layout.spinner_layout);
        fieldSpinner.setAdapter(adapter);
    }

    // ===== Start Services ====

    private void startGameService() {
        Log.d(TAG, "Starting game service");
        Intent serviceIntent = new Intent(getApplicationContext(), GameService.class);
        serviceIntent.putExtra(GameService.FIELD_ID_IDENTIFIER, selectedFieldId);
        serviceIntent.putExtra(GameDuration.IDENTIFIER, selectedGameDuration.getValue());
        startService(serviceIntent);
    }

    private void startGame() {
        Intent gameIntent = new Intent(getBaseContext(), GameMap.class);
        startActivity(gameIntent);
    }

}
