package de.uniba.kinf.geogames.esriguesstimate.data;

import android.util.Log;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;

/**
 * This class provides the GeoLocation object which extends the GeoPosition
 * class.
 * 
 * It provides the ability to store additional information, such as a name, a
 * description, a location type. GeoLocations can also have a id to map them on
 * their corresponding database entries.
 * 
 * @see GeoPosition
 * see DatabaseHandler
 * 
 * @author Thomas Heinz
 */
public class GeoLocation extends GeoPosition {

    public static final String LOGTAG = "GeoLocation";

	public static final String JSON_LOCATION_ARRAY = "locations";
	public static final String JSON_LOCATION_NAME = "name";
	public static final String JSON_LOCATION_COMMENT = "description";
	public static final String JSON_LOCATION_TYPE = "type";
	public static final String JSON_LOCATION_LAT = "lat";
	public static final String JSON_LOCATION_LNG = "lng";

	private int id;
	private String name;
	private String description;
	private int importance = 1;

    protected boolean hasGuess = false;
    protected int distance;

	/**
	 *
	 * NO LONGER IN USE!
	 *
	 * Creates a list of GeoLocations from a JSONObject.
	 * 
	 * The JSON object is parsed for a defined set of keys. With the
	 * corresponding values the list of GeoLocations is created.
	 * 
	 * 
	 * @param jsonObject
	 *            The JSONObject that should be converted to a list of
	 *            GeoLocations
	 * @return A list of GeoLocations on the successful parsing of the JSON
	 *         Object
	 * @throws org.json.JSONException
	 *             if the JSONObject does not contain valid data for the
	 *             conversion to a list of GeoLocations.
	 */
//	public static ArrayList<GeoLocation> createFromJson(JSONObject jsonObject)
//			throws JSONException {
//		ArrayList<GeoLocation> locations = new ArrayList<GeoLocation>();
//		//try {
//			JSONArray location_json_arr = jsonObject.getJSONArray(JSON_LOCATION_ARRAY);
//            Log.d(LOGTAG, "Trying to load: "+ location_json_arr);
//            for (int i = 0; i < location_json_arr.length(); i++) {
//				JSONObject obj = location_json_arr.getJSONObject(i);
//				String name = obj.getString(JSON_LOCATION_NAME);
//				String desc = obj.getString(JSON_LOCATION_COMMENT);
//				float lat = Float.parseFloat(obj.getString(JSON_LOCATION_LAT));
//				float lng = Float.parseFloat(obj.getString(JSON_LOCATION_LNG));
//				GeoLocation location = new GeoLocation(name, desc , lat, lng);
//				locations.add(location);
//			}
////		} catch (Exception e) {
////			throw new JSONException(e.getMessage());
////		}
//		return locations;
//	}

	/**
	 *
	 * NO LONGER IN USE!
	 *
	 * Creates a new GeoLocation that has an additional id that corresponds with
	 * an entry out of the local database.
	 * 
	 * @see de.uniba.kinf.geogames.guesstimate.data.GeoLocation
	 * see DatabaseHandler
	 * 
	 * @param id
	 * @param name
	 *            The name of the GeoLocations
	 * @param description
	 *            The description of the GeoLocation
	 * @param lat
	 *            The latitude value of the GeoLocation object
	 * @param lng
	 *            The longitude value of the GeoLocation object
	 * @return A new GeoLocation object with the given properties
	 */
//	public static GeoLocation createFromDatabase(int id, String name,
//			String description, double lat, double lng) {
//		GeoLocation location = new GeoLocation(name, description, lat,
//				lng);
//		location.id = id;
//		return location;
//	}

	// ===== Constructor =====

	/**
	 * Creates a new GeoLocation with the given data.
	 * 
	 * @param name
	 *            The name of the GeoLocations
	 * @param description
	 *            The description of the GeoLocation
	 * @param lat
	 *            The latitude value of the GeoLocation object
	 * @param lng
	 *            The longitude value of the GeoLocation object
	 */
	public GeoLocation(String name, String description, double lat, double lng) {
		super(lat, lng);
		this.id = -1;
		this.name = name;
		this.description = description;
	}

	// ===== Getter & Setter =====

	/**
	 * The GeoLocations id as an integer.
	 * 
	 * @return The GeoLocations id as an integer
	 */
	public int getID() {
		return id;
	}

	/**
	 * Returns if the GeoLocation has an ID and represents a database entry.
	 * 
	 * @return True if the GeoLocation has an ID and represents a database
	 *         entry, false otherwise
	 */
	public boolean inDB() {
		if (this.id == -1) {
			return false;
		}
		return true;
	}

	/**
	 * Returns the GeoLocations name.
	 * 
	 * @return The GeoLocations name as a string
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns the GeoLocations description.
	 * 
	 * @return The GeoLocations description as a string
	 */
	public String getDescription() {
		return description;
	}

    public void setDistanceGuess(int distance) {
        this.distance = distance;
        this.hasGuess = true;
    }

    public int getDistanceGuess() {
        return distance;
    }

    public boolean hasGuess() {
        return this.hasGuess;
    }

    public void removeGuess() {
        this.distance = -1;
        this.hasGuess = false;
    }

	public void setImportance(int importance) {
		this.importance = importance;
	}

	public int getImportance() {
		return importance;
	}
}
